SE3

Struct SE3 

pub struct SE3(/* private fields */);
SE(3) transformation represented as an isometry matrix.

An SE(3) transformation combines a rotation and a translation in 3D space. It combines a rotation matrix $R\in \text{SO}(3)$ and a translation vector $t \in \mathbb{R}^3$

Implementations

Source

impl SE3

pub fn new(translation: Vector3D, axis_angle: Vector3D) -> Self

Creates a new SE(3) transformation from a rotation (given as axis-angle) and a translation.

pub fn from_parts(translation: Vector3D, rotation: SpatialRotation) -> Self

Creates a new SE(3) transformation from a rotation and a translation.

pub fn identity() -> Self

Creates a new identity SE(3) transformation, with $R = I_3$ and $t = 0_3$.

pub fn inverse(&self) -> Self

Returns the inverse of the SE(3) transformation.

pub fn translation(&self) -> Vector3D

Returns the translation component of the SE(3) transformation.

pub fn rotation(&self) -> SpatialRotation

Returns the rotation component of the SE(3) transformation.

pub fn action_matrix(&self) -> Matrix6<f64>

Computes the action matrix of the SE(3) transformation.

Mathematically, the action matrix is: $$\begin{bmatrix}R & [t]_X R \\ 0 & R\end{bmatrix}$$ where $R$ is the rotation matrix and $[t]_X$ is the skew-symmetric matrix of the translation vector $t$.

pub fn dual_matrix(&self) -> Matrix6<f64>

Computes the dual action matrix of the SE(3) transformation.

Mathematically, the action matrix is: $$\begin{bmatrix}R & 0 \\ [t]_X R & R\end{bmatrix}$$ where $R$ is the rotation matrix and $[t]_X$ is the skew-symmetric matrix of the translation vector $t$.

pub fn inv_matrix(&self) -> Matrix6<f64>

Computes the inverse of the action matrix of the SE(3) transformation.

Source

impl SE3

pub fn act<T: ActSE3>(&self, obj: &T) -> T

Applies the SE(3) transformation to an object implementing the ActSE3 trait.

pub fn act_inv<T: ActSE3>(&self, obj: &T) -> T

Applies the inverse SE(3) transformation to an object implementing the ActSE3 trait.