This crate is part of the dynamics ecosystem, and is not intended for direct use.
Overview
This crate provides spatial algebra utilities for rigid body dynamics. It implements 6-dimensional vectors, encoding both rotational and translational components, as well as spatial transformations and operations.
Spatial algebra
Most computations of the main algorithms of dynamics (e.g. forward kinematics, inverse dynamics) are performed using spatial algebra.
Spatial vectors are 6-dimensional vectors that encode both rotational and translational components of motion or force,
making both equations and implementations more compact and efficient.
Core types
The core types provided by this crate are:
motion::SpatialMotion: represents spatial motion vectors (angular and linear velocity).force::SpatialForce: represents spatial force vectors (torque and force).se3::SE3: represents spatial transformations (rotation and translation), that is elements of the $\text{SE}(3)$ group.so3::SO3: represents 3D rotations, that is elements of the $\text{SO}(3)$ group.symmetric3::Symmetric3: represents symmetric 3x3 matrices, used for inertia tensors.
The following types are also provided for convenience:
vector3d::Vector3D: represents 3D vectors, used for underlying representations of motion and force vectors.vector6d::Vector6D: represents 6D vectors, used for underlying representations of spatial motion and force vectors.
Modules
- color
- Defines RGBA color representation, used for geometric visualization.
- configuration
- Defines configurations of multi-body systems and related operations.
- force
- Defines spatial forces and related operations.
- inertia
- Defines spatial inertia and related operations.
- jacobian
- Defines a Jacobian structure and related operations.
- motion
- Defines spatial motion and related operations.
- se3
- Defines the special Euclidean group SE(3) and related operations.
- so3
- Defines special orthogonal group SO(3) and related operations.
- symmetric3
- Defines symmetric matrices of size 3x3 and related operations.
- vector3d
- Defines 3D vectors and related operations.
- vector6d
- Defines spatial (6D) vectors and related operations.