pub struct Jacobian(/* private fields */);Expand description
Jacobian matrix, relating joint velocities to end-effector velocities.
The Jacobian is a matrix of size $6 \times n_v$ where $n_v$ is the number of joints in the robot model. Each column corresponds to the basis of the spatial velocity of the joint in the origin of the inertial frame.
Implementations
Sourceimpl Jacobian
impl Jacobian
Sourcepub fn update_column(&mut self, v_offset: usize, column_data: &[f64; 6])
pub fn update_column(&mut self, v_offset: usize, column_data: &[f64; 6])
Updates the specified column of the Jacobian matrix with the given data.
Arguments
v_offset- The index of the column to update, which corresponds to the joint index in the robot model.column_data- The data to update the column with, which should be a 6-dimensional vector representing the spatial velocity basis of the joint.
Sourcepub fn column(&self, v_offset: usize) -> JacobianColumn
pub fn column(&self, v_offset: usize) -> JacobianColumn
Returns a specified column of the Jacobian matrix as a JacobianColumn structure.
Arguments
v_offset- The index of the column to retrieve, which corresponds to the joint index in the robot model.
Returns
- A
JacobianColumnstructure containing the specified column of the Jacobian matrix, which represents the spatial velocity basis of the joint.