pub struct Symmetric3 { /* private fields */ }Expand description
A symmetric 3x3 matrix.
The matrix is stored in a compact form, only keeping the unique elements.
Implementations
Sourceimpl Symmetric3
impl Symmetric3
Sourcepub fn new(m11: f64, m22: f64, m33: f64, m12: f64, m13: f64, m23: f64) -> Self
pub fn new(m11: f64, m22: f64, m33: f64, m12: f64, m13: f64, m23: f64) -> Self
Creates a new Symmetric3 matrix from the given elements.
Arguments
m11,m22,m33- The diagonal elements.m12,m13,m23- The off-diagonal elements.
Sourcepub fn from_diagonal(diag: &[f64; 3]) -> Self
pub fn from_diagonal(diag: &[f64; 3]) -> Self
Creates a diagonal symmetric matrix from the given diagonal elements.
Arguments
diag- A vector containing the diagonal elements [m11, m22, m33].
Sourcepub fn skew_square(v: &Vector3D) -> Symmetric3
pub fn skew_square(v: &Vector3D) -> Symmetric3
Constructs the skew symmetric matrix associated to the given 3D vector.
Sourcepub fn rotate(&self, rotation: &SpatialRotation) -> Symmetric3
pub fn rotate(&self, rotation: &SpatialRotation) -> Symmetric3